#include <ESP8266WiFi.h>
#include <PubSubClient.h>

#define wifi_ssid "REPLACE"
#define wifi_password "REPLACE"

#define mqtt_server "192.168.1.XXX"  // MQTT Cloud address
#define topic "home/sourdough/distance"

int analogPin = A0;
int val = 0;
unsigned long nowTime;

WiFiClient espClient;
PubSubClient client(espClient);

void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600);
  pinMode(LED_BUILTIN, OUTPUT);
  setup_wifi();
  client.setServer(mqtt_server, 1883);
  Serial.print("Setup over.");
}


void setup_wifi() {
    delay(10);
    WiFi.begin(wifi_ssid, wifi_password);
    while (WiFi.status() != WL_CONNECTED) {
        delay(500);
        Serial.print(".");
    }
}

void reconnect() {
    // Loop until we're reconnected
    while (!client.connected()) {
        Serial.print("Attempting MQTT connection...");
        if (client.connect("sourdough_esp8266", "REPLACE", "REPLACE")) {
            Serial.println("connected");
        } else {
            Serial.print("failed, rc=");
            Serial.print(client.state());
            Serial.println(" try again in 5 seconds");
            delay(5000);
        }
    }
}

long lastMsg = -1;
long lastBlink = 0;

void loop() {
    if (!client.connected()) {
        reconnect();
    }
    client.loop();

    long now = millis();

    if (now - lastBlink > 5000) {
        blink();
        lastBlink = now;
    }
      
    if (now - lastMsg > 60000 || lastMsg == -1) {
        // Wait a few seconds between measurements
        lastMsg = now;

        float val = analogRead(analogPin)*0.0048828125;
        float distance = 13*pow(val, -1);

        String param = "{\"distance\":" + String(distance) + "}";
        client.publish(topic, param.c_str(), true);

        blink();  
        blink();
        blink();
        blink();
        blink();
        Serial.print("Last Value=");
        Serial.println(distance);
    }
}

void blink() {
        digitalWrite(LED_BUILTIN, LOW);   // Turn the LED on by making the voltage LOW
        delay(100);                      // Wait for a second
        digitalWrite(LED_BUILTIN, HIGH);  // Turn the LED off by making the voltage HIGH
        delay(100);  
}
